pub enum Value {}Expand description
Transmit FIFO empty. The meaning of this bit depends on the state of the FEN bit in the Line Control Register, LCR_H
- If the FIFO is disabled, this bit is set when the transmit holding register is empty.
- If the FIFO is enabled, the TXFE bit is set when the transmit FIFO is empty.
- This bit does not indicate if there is data in the transmit shift register.